Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Load ¶
func Load()
Types ¶
type EVM ¶
type EVM struct {
// contains filtered or unexported fields
}
func (*EVM) ExecuteContract ¶
func (e *EVM) ExecuteContract(isCreate bool) (ExecuteResult, error)
type EVMParam ¶
type EVMParam struct {
MaxStackDepth int
ExternalStore storage.IExternalStorage
UpperStorage *storage.Storage
ResultCallback EVMResultCallback
Context *environment.Context
}
type EVMResultCallback ¶
type EVMResultCallback func(result *ExecuteResult, err error)
Source Files
¶
- evm.go
Directories
¶
| Path | Synopsis |
|---|---|
|
Package math provides integer math utilities.
|
Package math provides integer math utilities. |
|
* Copyright 2020 The SealEVM Authors * * Licensed under the Apache License, Version 2.0 (the "License"); * you may not use this file except in compliance with the License.
|
* Copyright 2020 The SealEVM Authors * * Licensed under the Apache License, Version 2.0 (the "License"); * you may not use this file except in compliance with the License. |
Click to show internal directories.
Click to hide internal directories.