Documentation
¶
Index ¶
- type InstancesManager
- func (*InstancesManager) AfterSchedule(blockFingerprint string, blockHeight uint64)
- func (*InstancesManager) BeforeSchedule(blockFingerprint string, blockHeight uint64)
- func (*InstancesManager) NewRuntimeInstance(txSimContext protocol.TxSimContext, chainId, method string, codePath string, ...) (protocol.RuntimeInstance, error)
- func (*InstancesManager) StartVM() error
- func (*InstancesManager) StopVM() error
- type RuntimeInstance
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type InstancesManager ¶
type InstancesManager struct {
}
InstancesManager manager of evm instances
func (*InstancesManager) AfterSchedule ¶
func (*InstancesManager) AfterSchedule(blockFingerprint string, blockHeight uint64)
AfterSchedule do sth. after schedule a block
func (*InstancesManager) BeforeSchedule ¶
func (*InstancesManager) BeforeSchedule(blockFingerprint string, blockHeight uint64)
BeforeSchedule do sth. before schedule a block
func (*InstancesManager) NewRuntimeInstance ¶
func (*InstancesManager) NewRuntimeInstance(txSimContext protocol.TxSimContext, chainId, method string, codePath string, contract *commonPb.Contract, byteCode []byte, log protocol.Logger) (protocol.RuntimeInstance, error)
NewRuntimeInstance new an evm instance
type RuntimeInstance ¶
type RuntimeInstance struct {
Method string // invoke contract method
ChainId string // chain id
//Address *evmutils.Int //address
Contract *commonPb.Contract // contract info
Log protocol.Logger
TxSimContext protocol.TxSimContext
ContractEvent []*commonPb.ContractEvent
}
RuntimeInstance evm runtime
func (*RuntimeInstance) Invoke ¶
func (r *RuntimeInstance) Invoke(contract *commonPb.Contract, method string, byteCode []byte, parameters map[string][]byte, txSimContext protocol.TxSimContext, gasUsed uint64) ( contractResult *commonPb.ContractResult, specialTxType protocol.ExecOrderTxType)
Invoke contract by call vm, implement protocol.RuntimeInstance
Source Files
¶
- runtime.go
Directories
¶
| Path | Synopsis |
|---|---|
|
math
Package math provides integer math utilities.
|
Package math provides integer math utilities. |
|
precompiledContracts
* Copyright 2020 The SealEVM Authors * * Licensed under the Apache License, Version 2.0 (the "License"); * you may not use this file except in compliance with the License.
|
* Copyright 2020 The SealEVM Authors * * Licensed under the Apache License, Version 2.0 (the "License"); * you may not use this file except in compliance with the License. |
Click to show internal directories.
Click to hide internal directories.